@@ -13,7 +13,7 @@ from typing import TYPE_CHECKING, Any, Callable, Iterable, Iterator, Sequence
 import qtpy
 import superqt
 from qtpy import QtWidgets as QtW
-from qtpy.QtCore import QEvent, QObject, Qt, Signal
+from qtpy.QtCore import QEvent, QObject, QSize, Qt, Signal
 from qtpy.QtGui import (
     QFont,
     QFontMetrics,
@@ -181,6 +181,8 @@ class QBaseWidget(protocols.WidgetProtocol):
             ) from None
 
         img = self._qwidget.grab().toImage()
+        if img.format() != QImage.Format_ARGB32:
+            img = img.convertToFormat(QImage.Format_ARGB32)
         bits = img.constBits()
         h, w, c = img.height(), img.width(), 4
         if qtpy.API_NAME.startswith("PySide"):
@@ -1217,6 +1219,63 @@ class TimeEdit(QBaseValueWidget):
             return self._qwidget.time().toPyTime()
 
 
+class ToolBar(QBaseWidget):
+    _qwidget: QtW.QToolBar
+
+    def __init__(self, **kwargs: Any) -> None:
+        super().__init__(QtW.QToolBar, **kwargs)
+        self._qwidget.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextUnderIcon)
+        self._event_filter.paletteChanged.connect(self._on_palette_change)
+
+    def _on_palette_change(self):
+        for action in self._qwidget.actions():
+            if icon := action.data():
+                if qicon := _get_qicon(icon, None, palette=self._qwidget.palette()):
+                    action.setIcon(qicon)
+
+    def _mgui_add_button(self, text: str, icon: str, callback: Callable) -> None:
+        """Add an action to the toolbar."""
+        act = self._qwidget.addAction(text, callback)
+        if qicon := _get_qicon(icon, None, palette=self._qwidget.palette()):
+            act.setIcon(qicon)
+            act.setData(icon)
+
+    def _mgui_add_separator(self) -> None:
+        """Add a separator line to the toolbar."""
+        self._qwidget.addSeparator()
+
+    def _mgui_add_spacer(self) -> None:
+        """Add a spacer to the toolbar."""
+        empty = QtW.QWidget()
+        empty.setSizePolicy(
+            QtW.QSizePolicy.Policy.Expanding, QtW.QSizePolicy.Policy.Preferred
+        )
+        self._qwidget.addWidget(empty)
+
+    def _mgui_add_widget(self, widget: Widget) -> None:
+        """Add a widget to the toolbar."""
+        self._qwidget.addWidget(widget.native)
+
+    def _mgui_get_icon_size(self) -> tuple[int, int] | None:
+        """Return the icon size of the toolbar."""
+        sz = self._qwidget.iconSize()
+        return None if sz.isNull() else (sz.width(), sz.height())
+
+    def _mgui_set_icon_size(self, size: int | tuple[int, int] | None) -> None:
+        """Set the icon size of the toolbar."""
+        if isinstance(size, int):
+            _size = QSize(size, size)
+        elif isinstance(size, tuple):
+            _size = QSize(size[0], size[1])
+        else:
+            _size = QSize()
+        self._qwidget.setIconSize(_size)
+
+    def _mgui_clear(self) -> None:
+        """Clear the toolbar."""
+        self._qwidget.clear()
+
+
 class Dialog(QBaseWidget, protocols.ContainerProtocol):
     def __init__(
         self, layout="vertical", scrollable: bool = False, **kwargs: Any
