@@ -46,6 +46,7 @@ from magicgui.widgets.bases import (
     MultiValuedSliderWidget,
     RangedWidget,
     SliderWidget,
+    ToolBarWidget,
     TransformedRangedWidget,
     ValueWidget,
     Widget,
@@ -610,28 +611,24 @@ class ListEdit(Container[ValueWidget[_V]]):
     ----------
     value : Iterable, optional
         The starting value for the widget.
-    layout : str, optional
-        The layout for the container.  must be one of ``{'horizontal',
-        'vertical'}``. by default "horizontal"
     nullable : bool
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     options: dict, optional
         Widget options of child widgets.
-    **kwargs : Any
-        All additional keyword arguments are passed to `Container` constructor.
     """
 
-    def __init__(  # type: ignore [misc]  # overlap between names
+    def __init__(
         self,
         value: Iterable[_V] | _Undefined = Undefined,
-        layout: str = "horizontal",
         nullable: bool = False,
         options: dict | None = None,
-        **kwargs: Unpack[ContainerKwargs],
+        **container_kwargs: Unpack[ContainerKwargs],
     ) -> None:
         self._args_type: type | None = None
         self._nullable = nullable
-        super().__init__(layout=layout, labels=False, **kwargs)
+        container_kwargs.setdefault("layout", "horizontal")
+        container_kwargs.setdefault("labels", False)
+        super().__init__(**container_kwargs)
         self.margins = (0, 0, 0, 0)
 
         if not isinstance(value, _Undefined):
@@ -650,7 +647,7 @@ class ListEdit(Container[ValueWidget[_V]]):
         button_plus = PushButton(text="+", name="plus")
         button_minus = PushButton(text="-", name="minus")
 
-        if layout == "horizontal":
+        if self.layout == "horizontal":
             button_plus.max_width = 40
             button_minus.max_width = 40
 
@@ -863,15 +860,10 @@ class TupleEdit(Container[ValueWidget]):
     ----------
     value : Iterable, optional
         The starting value for the widget.
-    layout : str, optional
-        The layout for the container.  must be one of ``{'horizontal',
-        'vertical'}``. by default "horizontal"
     nullable : bool
         If `True`, the widget will accepts `None` as a valid value, by default `False`.
     options: dict, optional
         Widget options of child widgets.
-    **kwargs : Any
-        All additional keyword arguments are passed to `Container` constructor.
     """
 
     def __init__(
@@ -884,7 +876,8 @@ class TupleEdit(Container[ValueWidget]):
     ) -> None:
         self._nullable = nullable
         self._args_types: tuple[type, ...] | None = None
-        container_kwargs["labels"] = False
+        container_kwargs.setdefault("labels", False)
+        container_kwargs.setdefault("layout", "horizontal")
         super().__init__(**container_kwargs)
         self._child_options = options or {}
         self.margins = (0, 0, 0, 0)
@@ -969,6 +962,11 @@ class TupleEdit(Container[ValueWidget]):
         self.changed.emit(self.value)
 
 
+@backend_widget
+class ToolBar(ToolBarWidget):
+    """Toolbar that contains a set of controls."""
+
+
 class _LabeledWidget(Container):
     """Simple container that wraps a widget and provides a label."""
 
