@@ -30,10 +30,16 @@ from magicgui.widgets.bases import ValueWidget
 if TYPE_CHECKING:
     from pathlib import Path
 
+    from typing_extensions import ParamSpec
+
     from magicgui.application import Application, AppRef  # noqa: F401
     from magicgui.widgets import TextEdit
     from magicgui.widgets.protocols import ContainerProtocol, MainWindowProtocol
 
+    _P = ParamSpec("_P")
+else:
+    _P = TypeVar("_P")  # easier runtime dependency than ParamSpec
+
 
 def _inject_tooltips_from_docstrings(
     docstring: str | None, sig: MagicSignature
@@ -70,7 +76,7 @@ _KT = TypeVar("_KT")
 _VT = TypeVar("_VT")
 
 
-class FunctionGui(Container, Generic[_R]):
+class FunctionGui(Container, Generic[_P, _R]):
     """Wrapper for a container of widgets representing a callable object.
 
     Parameters
@@ -129,7 +135,7 @@ class FunctionGui(Container, Generic[_R]):
 
     def __init__(
         self,
-        function: Callable[..., _R],
+        function: Callable[_P, _R],
         call_button: bool | str | None = None,
         layout: str = "vertical",
         scrollable: bool = False,
@@ -265,7 +271,7 @@ class FunctionGui(Container, Generic[_R]):
 
     @property
     def return_annotation(self) -> Any:
-        """Return annotation to use when converting to [inspect.Signature][].
+        """Return annotation for [inspect.Signature][inspect.Signature] conversion.
 
         ForwardRefs will be resolve when setting the annotation.
         """
@@ -276,9 +282,12 @@ class FunctionGui(Container, Generic[_R]):
         """Return a MagicSignature object representing the current state of the gui."""
         return super().__signature__.replace(return_annotation=self.return_annotation)
 
-    def __call__(self, *args: Any, update_widget: bool = False, **kwargs: Any) -> _R:
+    def __call__(self, *args: _P.args, **kwargs: _P.kwargs) -> _R:
         """Call the original function with the current parameter values from the Gui.
 
+        You may pass a `update_widget=True` keyword argument to update the widget
+        values to match the current parameter values before calling the function.
+
         It is also possible to override the current parameter values from the GUI by
         providing args/kwargs to the function call.  Only those provided will override
         the ones from the gui.  A `called` signal will also be emitted with the results.
@@ -298,6 +307,8 @@ class FunctionGui(Container, Generic[_R]):
         gui()  # calls the original function with the current parameters
         ```
         """
+        update_widget: bool = bool(kwargs.pop("update_widget", False))
+
         sig = self.__signature__
         try:
             bound = sig.bind(*args, **kwargs)
@@ -441,12 +452,12 @@ class FunctionGui(Container, Generic[_R]):
         super()._load(path or self._dump_path, quiet=quiet)
 
 
-class MainFunctionGui(FunctionGui[_R], MainWindow):
+class MainFunctionGui(FunctionGui[_P, _R], MainWindow):
     """Container of widgets as a Main Application Window."""
 
     _widget: MainWindowProtocol
 
-    def __init__(self, function: Callable, *args: Any, **kwargs: Any) -> None:
+    def __init__(self, function: Callable[_P, _R], *args: Any, **kwargs: Any) -> None:
         super().__init__(function, *args, **kwargs)
         self.create_menu_item("Help", "Documentation", callback=self._show_docs)
         self._help_text_edit: TextEdit | None = None
@@ -488,7 +499,7 @@ def _function_name_pointing_to_widget(function_gui: FunctionGui) -> Iterator[Non
     In standard `@magicgui` usage, this will have been the case anyway.
     Doing this here allows the function name in a `@magic_factory`-decorated function
     to *also* refer to the function gui instance created by the factory, (rather than
-    to the [~magicgui._magicgui.MagicFactory][] object).
+    to the [~magicgui._magicgui.MagicFactory][magicgui._magicgui.MagicFactory] object).
 
     Examples
     --------
